# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities
from . import outputs
from ._enums import *
from ._inputs import *

__all__ = ['LinkedServiceArgs', 'LinkedService']

@pulumi.input_type
class LinkedServiceArgs:
    def __init__(__self__, *,
                 factory_name: pulumi.Input[str],
                 properties: pulumi.Input[Union['AmazonMWSLinkedServiceArgs', 'AmazonRedshiftLinkedServiceArgs', 'AmazonS3LinkedServiceArgs', 'AzureBatchLinkedServiceArgs', 'AzureDataLakeAnalyticsLinkedServiceArgs', 'AzureDataLakeStoreLinkedServiceArgs', 'AzureDatabricksLinkedServiceArgs', 'AzureKeyVaultLinkedServiceArgs', 'AzureMLLinkedServiceArgs', 'AzureMySqlLinkedServiceArgs', 'AzurePostgreSqlLinkedServiceArgs', 'AzureSearchLinkedServiceArgs', 'AzureSqlDWLinkedServiceArgs', 'AzureSqlDatabaseLinkedServiceArgs', 'AzureStorageLinkedServiceArgs', 'CassandraLinkedServiceArgs', 'ConcurLinkedServiceArgs', 'CosmosDbLinkedServiceArgs', 'CouchbaseLinkedServiceArgs', 'CustomDataSourceLinkedServiceArgs', 'Db2LinkedServiceArgs', 'DrillLinkedServiceArgs', 'DynamicsLinkedServiceArgs', 'EloquaLinkedServiceArgs', 'FileServerLinkedServiceArgs', 'FtpServerLinkedServiceArgs', 'GoogleBigQueryLinkedServiceArgs', 'GreenplumLinkedServiceArgs', 'HBaseLinkedServiceArgs', 'HDInsightLinkedServiceArgs', 'HDInsightOnDemandLinkedServiceArgs', 'HdfsLinkedServiceArgs', 'HiveLinkedServiceArgs', 'HttpLinkedServiceArgs', 'HubspotLinkedServiceArgs', 'ImpalaLinkedServiceArgs', 'JiraLinkedServiceArgs', 'MagentoLinkedServiceArgs', 'MariaDBLinkedServiceArgs', 'MarketoLinkedServiceArgs', 'MongoDbLinkedServiceArgs', 'MySqlLinkedServiceArgs', 'NetezzaLinkedServiceArgs', 'ODataLinkedServiceArgs', 'OdbcLinkedServiceArgs', 'OracleLinkedServiceArgs', 'PaypalLinkedServiceArgs', 'PhoenixLinkedServiceArgs', 'PostgreSqlLinkedServiceArgs', 'PrestoLinkedServiceArgs', 'QuickBooksLinkedServiceArgs', 'ResponsysLinkedServiceArgs', 'SalesforceLinkedServiceArgs', 'SalesforceMarketingCloudLinkedServiceArgs', 'SapBWLinkedServiceArgs', 'SapCloudForCustomerLinkedServiceArgs', 'SapEccLinkedServiceArgs', 'SapHanaLinkedServiceArgs', 'ServiceNowLinkedServiceArgs', 'SftpServerLinkedServiceArgs', 'ShopifyLinkedServiceArgs', 'SparkLinkedServiceArgs', 'SqlServerLinkedServiceArgs', 'SquareLinkedServiceArgs', 'SybaseLinkedServiceArgs', 'TeradataLinkedServiceArgs', 'VerticaLinkedServiceArgs', 'WebLinkedServiceArgs', 'XeroLinkedServiceArgs', 'ZohoLinkedServiceArgs']],
                 resource_group_name: pulumi.Input[str],
                 linked_service_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LinkedService resource.
        :param pulumi.Input[str] factory_name: The factory name.
        :param pulumi.Input[Union['AmazonMWSLinkedServiceArgs', 'AmazonRedshiftLinkedServiceArgs', 'AmazonS3LinkedServiceArgs', 'AzureBatchLinkedServiceArgs', 'AzureDataLakeAnalyticsLinkedServiceArgs', 'AzureDataLakeStoreLinkedServiceArgs', 'AzureDatabricksLinkedServiceArgs', 'AzureKeyVaultLinkedServiceArgs', 'AzureMLLinkedServiceArgs', 'AzureMySqlLinkedServiceArgs', 'AzurePostgreSqlLinkedServiceArgs', 'AzureSearchLinkedServiceArgs', 'AzureSqlDWLinkedServiceArgs', 'AzureSqlDatabaseLinkedServiceArgs', 'AzureStorageLinkedServiceArgs', 'CassandraLinkedServiceArgs', 'ConcurLinkedServiceArgs', 'CosmosDbLinkedServiceArgs', 'CouchbaseLinkedServiceArgs', 'CustomDataSourceLinkedServiceArgs', 'Db2LinkedServiceArgs', 'DrillLinkedServiceArgs', 'DynamicsLinkedServiceArgs', 'EloquaLinkedServiceArgs', 'FileServerLinkedServiceArgs', 'FtpServerLinkedServiceArgs', 'GoogleBigQueryLinkedServiceArgs', 'GreenplumLinkedServiceArgs', 'HBaseLinkedServiceArgs', 'HDInsightLinkedServiceArgs', 'HDInsightOnDemandLinkedServiceArgs', 'HdfsLinkedServiceArgs', 'HiveLinkedServiceArgs', 'HttpLinkedServiceArgs', 'HubspotLinkedServiceArgs', 'ImpalaLinkedServiceArgs', 'JiraLinkedServiceArgs', 'MagentoLinkedServiceArgs', 'MariaDBLinkedServiceArgs', 'MarketoLinkedServiceArgs', 'MongoDbLinkedServiceArgs', 'MySqlLinkedServiceArgs', 'NetezzaLinkedServiceArgs', 'ODataLinkedServiceArgs', 'OdbcLinkedServiceArgs', 'OracleLinkedServiceArgs', 'PaypalLinkedServiceArgs', 'PhoenixLinkedServiceArgs', 'PostgreSqlLinkedServiceArgs', 'PrestoLinkedServiceArgs', 'QuickBooksLinkedServiceArgs', 'ResponsysLinkedServiceArgs', 'SalesforceLinkedServiceArgs', 'SalesforceMarketingCloudLinkedServiceArgs', 'SapBWLinkedServiceArgs', 'SapCloudForCustomerLinkedServiceArgs', 'SapEccLinkedServiceArgs', 'SapHanaLinkedServiceArgs', 'ServiceNowLinkedServiceArgs', 'SftpServerLinkedServiceArgs', 'ShopifyLinkedServiceArgs', 'SparkLinkedServiceArgs', 'SqlServerLinkedServiceArgs', 'SquareLinkedServiceArgs', 'SybaseLinkedServiceArgs', 'TeradataLinkedServiceArgs', 'VerticaLinkedServiceArgs', 'WebLinkedServiceArgs', 'XeroLinkedServiceArgs', 'ZohoLinkedServiceArgs']] properties: Properties of linked service.
        :param pulumi.Input[str] resource_group_name: The resource group name.
        :param pulumi.Input[str] linked_service_name: The linked service name.
        """
        pulumi.set(__self__, "factory_name", factory_name)
        pulumi.set(__self__, "properties", properties)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if linked_service_name is not None:
            pulumi.set(__self__, "linked_service_name", linked_service_name)

    @property
    @pulumi.getter(name="factoryName")
    def factory_name(self) -> pulumi.Input[str]:
        """
        The factory name.
        """
        return pulumi.get(self, "factory_name")

    @factory_name.setter
    def factory_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "factory_name", value)

    @property
    @pulumi.getter
    def properties(self) -> pulumi.Input[Union['AmazonMWSLinkedServiceArgs', 'AmazonRedshiftLinkedServiceArgs', 'AmazonS3LinkedServiceArgs', 'AzureBatchLinkedServiceArgs', 'AzureDataLakeAnalyticsLinkedServiceArgs', 'AzureDataLakeStoreLinkedServiceArgs', 'AzureDatabricksLinkedServiceArgs', 'AzureKeyVaultLinkedServiceArgs', 'AzureMLLinkedServiceArgs', 'AzureMySqlLinkedServiceArgs', 'AzurePostgreSqlLinkedServiceArgs', 'AzureSearchLinkedServiceArgs', 'AzureSqlDWLinkedServiceArgs', 'AzureSqlDatabaseLinkedServiceArgs', 'AzureStorageLinkedServiceArgs', 'CassandraLinkedServiceArgs', 'ConcurLinkedServiceArgs', 'CosmosDbLinkedServiceArgs', 'CouchbaseLinkedServiceArgs', 'CustomDataSourceLinkedServiceArgs', 'Db2LinkedServiceArgs', 'DrillLinkedServiceArgs', 'DynamicsLinkedServiceArgs', 'EloquaLinkedServiceArgs', 'FileServerLinkedServiceArgs', 'FtpServerLinkedServiceArgs', 'GoogleBigQueryLinkedServiceArgs', 'GreenplumLinkedServiceArgs', 'HBaseLinkedServiceArgs', 'HDInsightLinkedServiceArgs', 'HDInsightOnDemandLinkedServiceArgs', 'HdfsLinkedServiceArgs', 'HiveLinkedServiceArgs', 'HttpLinkedServiceArgs', 'HubspotLinkedServiceArgs', 'ImpalaLinkedServiceArgs', 'JiraLinkedServiceArgs', 'MagentoLinkedServiceArgs', 'MariaDBLinkedServiceArgs', 'MarketoLinkedServiceArgs', 'MongoDbLinkedServiceArgs', 'MySqlLinkedServiceArgs', 'NetezzaLinkedServiceArgs', 'ODataLinkedServiceArgs', 'OdbcLinkedServiceArgs', 'OracleLinkedServiceArgs', 'PaypalLinkedServiceArgs', 'PhoenixLinkedServiceArgs', 'PostgreSqlLinkedServiceArgs', 'PrestoLinkedServiceArgs', 'QuickBooksLinkedServiceArgs', 'ResponsysLinkedServiceArgs', 'SalesforceLinkedServiceArgs', 'SalesforceMarketingCloudLinkedServiceArgs', 'SapBWLinkedServiceArgs', 'SapCloudForCustomerLinkedServiceArgs', 'SapEccLinkedServiceArgs', 'SapHanaLinkedServiceArgs', 'ServiceNowLinkedServiceArgs', 'SftpServerLinkedServiceArgs', 'ShopifyLinkedServiceArgs', 'SparkLinkedServiceArgs', 'SqlServerLinkedServiceArgs', 'SquareLinkedServiceArgs', 'SybaseLinkedServiceArgs', 'TeradataLinkedServiceArgs', 'VerticaLinkedServiceArgs', 'WebLinkedServiceArgs', 'XeroLinkedServiceArgs', 'ZohoLinkedServiceArgs']]:
        """
        Properties of linked service.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: pulumi.Input[Union['AmazonMWSLinkedServiceArgs', 'AmazonRedshiftLinkedServiceArgs', 'AmazonS3LinkedServiceArgs', 'AzureBatchLinkedServiceArgs', 'AzureDataLakeAnalyticsLinkedServiceArgs', 'AzureDataLakeStoreLinkedServiceArgs', 'AzureDatabricksLinkedServiceArgs', 'AzureKeyVaultLinkedServiceArgs', 'AzureMLLinkedServiceArgs', 'AzureMySqlLinkedServiceArgs', 'AzurePostgreSqlLinkedServiceArgs', 'AzureSearchLinkedServiceArgs', 'AzureSqlDWLinkedServiceArgs', 'AzureSqlDatabaseLinkedServiceArgs', 'AzureStorageLinkedServiceArgs', 'CassandraLinkedServiceArgs', 'ConcurLinkedServiceArgs', 'CosmosDbLinkedServiceArgs', 'CouchbaseLinkedServiceArgs', 'CustomDataSourceLinkedServiceArgs', 'Db2LinkedServiceArgs', 'DrillLinkedServiceArgs', 'DynamicsLinkedServiceArgs', 'EloquaLinkedServiceArgs', 'FileServerLinkedServiceArgs', 'FtpServerLinkedServiceArgs', 'GoogleBigQueryLinkedServiceArgs', 'GreenplumLinkedServiceArgs', 'HBaseLinkedServiceArgs', 'HDInsightLinkedServiceArgs', 'HDInsightOnDemandLinkedServiceArgs', 'HdfsLinkedServiceArgs', 'HiveLinkedServiceArgs', 'HttpLinkedServiceArgs', 'HubspotLinkedServiceArgs', 'ImpalaLinkedServiceArgs', 'JiraLinkedServiceArgs', 'MagentoLinkedServiceArgs', 'MariaDBLinkedServiceArgs', 'MarketoLinkedServiceArgs', 'MongoDbLinkedServiceArgs', 'MySqlLinkedServiceArgs', 'NetezzaLinkedServiceArgs', 'ODataLinkedServiceArgs', 'OdbcLinkedServiceArgs', 'OracleLinkedServiceArgs', 'PaypalLinkedServiceArgs', 'PhoenixLinkedServiceArgs', 'PostgreSqlLinkedServiceArgs', 'PrestoLinkedServiceArgs', 'QuickBooksLinkedServiceArgs', 'ResponsysLinkedServiceArgs', 'SalesforceLinkedServiceArgs', 'SalesforceMarketingCloudLinkedServiceArgs', 'SapBWLinkedServiceArgs', 'SapCloudForCustomerLinkedServiceArgs', 'SapEccLinkedServiceArgs', 'SapHanaLinkedServiceArgs', 'ServiceNowLinkedServiceArgs', 'SftpServerLinkedServiceArgs', 'ShopifyLinkedServiceArgs', 'SparkLinkedServiceArgs', 'SqlServerLinkedServiceArgs', 'SquareLinkedServiceArgs', 'SybaseLinkedServiceArgs', 'TeradataLinkedServiceArgs', 'VerticaLinkedServiceArgs', 'WebLinkedServiceArgs', 'XeroLinkedServiceArgs', 'ZohoLinkedServiceArgs']]):
        pulumi.set(self, "properties", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The resource group name.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="linkedServiceName")
    def linked_service_name(self) -> Optional[pulumi.Input[str]]:
        """
        The linked service name.
        """
        return pulumi.get(self, "linked_service_name")

    @linked_service_name.setter
    def linked_service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "linked_service_name", value)


warnings.warn("""Version 2017-09-01-preview will be removed in v2 of the provider.""", DeprecationWarning)


class LinkedService(pulumi.CustomResource):
    warnings.warn("""Version 2017-09-01-preview will be removed in v2 of the provider.""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 factory_name: Optional[pulumi.Input[str]] = None,
                 linked_service_name: Optional[pulumi.Input[str]] = None,
                 properties: Optional[pulumi.Input[Union[pulumi.InputType['AmazonMWSLinkedServiceArgs'], pulumi.InputType['AmazonRedshiftLinkedServiceArgs'], pulumi.InputType['AmazonS3LinkedServiceArgs'], pulumi.InputType['AzureBatchLinkedServiceArgs'], pulumi.InputType['AzureDataLakeAnalyticsLinkedServiceArgs'], pulumi.InputType['AzureDataLakeStoreLinkedServiceArgs'], pulumi.InputType['AzureDatabricksLinkedServiceArgs'], pulumi.InputType['AzureKeyVaultLinkedServiceArgs'], pulumi.InputType['AzureMLLinkedServiceArgs'], pulumi.InputType['AzureMySqlLinkedServiceArgs'], pulumi.InputType['AzurePostgreSqlLinkedServiceArgs'], pulumi.InputType['AzureSearchLinkedServiceArgs'], pulumi.InputType['AzureSqlDWLinkedServiceArgs'], pulumi.InputType['AzureSqlDatabaseLinkedServiceArgs'], pulumi.InputType['AzureStorageLinkedServiceArgs'], pulumi.InputType['CassandraLinkedServiceArgs'], pulumi.InputType['ConcurLinkedServiceArgs'], pulumi.InputType['CosmosDbLinkedServiceArgs'], pulumi.InputType['CouchbaseLinkedServiceArgs'], pulumi.InputType['CustomDataSourceLinkedServiceArgs'], pulumi.InputType['Db2LinkedServiceArgs'], pulumi.InputType['DrillLinkedServiceArgs'], pulumi.InputType['DynamicsLinkedServiceArgs'], pulumi.InputType['EloquaLinkedServiceArgs'], pulumi.InputType['FileServerLinkedServiceArgs'], pulumi.InputType['FtpServerLinkedServiceArgs'], pulumi.InputType['GoogleBigQueryLinkedServiceArgs'], pulumi.InputType['GreenplumLinkedServiceArgs'], pulumi.InputType['HBaseLinkedServiceArgs'], pulumi.InputType['HDInsightLinkedServiceArgs'], pulumi.InputType['HDInsightOnDemandLinkedServiceArgs'], pulumi.InputType['HdfsLinkedServiceArgs'], pulumi.InputType['HiveLinkedServiceArgs'], pulumi.InputType['HttpLinkedServiceArgs'], pulumi.InputType['HubspotLinkedServiceArgs'], pulumi.InputType['ImpalaLinkedServiceArgs'], pulumi.InputType['JiraLinkedServiceArgs'], pulumi.InputType['MagentoLinkedServiceArgs'], pulumi.InputType['MariaDBLinkedServiceArgs'], pulumi.InputType['MarketoLinkedServiceArgs'], pulumi.InputType['MongoDbLinkedServiceArgs'], pulumi.InputType['MySqlLinkedServiceArgs'], pulumi.InputType['NetezzaLinkedServiceArgs'], pulumi.InputType['ODataLinkedServiceArgs'], pulumi.InputType['OdbcLinkedServiceArgs'], pulumi.InputType['OracleLinkedServiceArgs'], pulumi.InputType['PaypalLinkedServiceArgs'], pulumi.InputType['PhoenixLinkedServiceArgs'], pulumi.InputType['PostgreSqlLinkedServiceArgs'], pulumi.InputType['PrestoLinkedServiceArgs'], pulumi.InputType['QuickBooksLinkedServiceArgs'], pulumi.InputType['ResponsysLinkedServiceArgs'], pulumi.InputType['SalesforceLinkedServiceArgs'], pulumi.InputType['SalesforceMarketingCloudLinkedServiceArgs'], pulumi.InputType['SapBWLinkedServiceArgs'], pulumi.InputType['SapCloudForCustomerLinkedServiceArgs'], pulumi.InputType['SapEccLinkedServiceArgs'], pulumi.InputType['SapHanaLinkedServiceArgs'], pulumi.InputType['ServiceNowLinkedServiceArgs'], pulumi.InputType['SftpServerLinkedServiceArgs'], pulumi.InputType['ShopifyLinkedServiceArgs'], pulumi.InputType['SparkLinkedServiceArgs'], pulumi.InputType['SqlServerLinkedServiceArgs'], pulumi.InputType['SquareLinkedServiceArgs'], pulumi.InputType['SybaseLinkedServiceArgs'], pulumi.InputType['TeradataLinkedServiceArgs'], pulumi.InputType['VerticaLinkedServiceArgs'], pulumi.InputType['WebLinkedServiceArgs'], pulumi.InputType['XeroLinkedServiceArgs'], pulumi.InputType['ZohoLinkedServiceArgs']]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Linked service resource type.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] factory_name: The factory name.
        :param pulumi.Input[str] linked_service_name: The linked service name.
        :param pulumi.Input[Union[pulumi.InputType['AmazonMWSLinkedServiceArgs'], pulumi.InputType['AmazonRedshiftLinkedServiceArgs'], pulumi.InputType['AmazonS3LinkedServiceArgs'], pulumi.InputType['AzureBatchLinkedServiceArgs'], pulumi.InputType['AzureDataLakeAnalyticsLinkedServiceArgs'], pulumi.InputType['AzureDataLakeStoreLinkedServiceArgs'], pulumi.InputType['AzureDatabricksLinkedServiceArgs'], pulumi.InputType['AzureKeyVaultLinkedServiceArgs'], pulumi.InputType['AzureMLLinkedServiceArgs'], pulumi.InputType['AzureMySqlLinkedServiceArgs'], pulumi.InputType['AzurePostgreSqlLinkedServiceArgs'], pulumi.InputType['AzureSearchLinkedServiceArgs'], pulumi.InputType['AzureSqlDWLinkedServiceArgs'], pulumi.InputType['AzureSqlDatabaseLinkedServiceArgs'], pulumi.InputType['AzureStorageLinkedServiceArgs'], pulumi.InputType['CassandraLinkedServiceArgs'], pulumi.InputType['ConcurLinkedServiceArgs'], pulumi.InputType['CosmosDbLinkedServiceArgs'], pulumi.InputType['CouchbaseLinkedServiceArgs'], pulumi.InputType['CustomDataSourceLinkedServiceArgs'], pulumi.InputType['Db2LinkedServiceArgs'], pulumi.InputType['DrillLinkedServiceArgs'], pulumi.InputType['DynamicsLinkedServiceArgs'], pulumi.InputType['EloquaLinkedServiceArgs'], pulumi.InputType['FileServerLinkedServiceArgs'], pulumi.InputType['FtpServerLinkedServiceArgs'], pulumi.InputType['GoogleBigQueryLinkedServiceArgs'], pulumi.InputType['GreenplumLinkedServiceArgs'], pulumi.InputType['HBaseLinkedServiceArgs'], pulumi.InputType['HDInsightLinkedServiceArgs'], pulumi.InputType['HDInsightOnDemandLinkedServiceArgs'], pulumi.InputType['HdfsLinkedServiceArgs'], pulumi.InputType['HiveLinkedServiceArgs'], pulumi.InputType['HttpLinkedServiceArgs'], pulumi.InputType['HubspotLinkedServiceArgs'], pulumi.InputType['ImpalaLinkedServiceArgs'], pulumi.InputType['JiraLinkedServiceArgs'], pulumi.InputType['MagentoLinkedServiceArgs'], pulumi.InputType['MariaDBLinkedServiceArgs'], pulumi.InputType['MarketoLinkedServiceArgs'], pulumi.InputType['MongoDbLinkedServiceArgs'], pulumi.InputType['MySqlLinkedServiceArgs'], pulumi.InputType['NetezzaLinkedServiceArgs'], pulumi.InputType['ODataLinkedServiceArgs'], pulumi.InputType['OdbcLinkedServiceArgs'], pulumi.InputType['OracleLinkedServiceArgs'], pulumi.InputType['PaypalLinkedServiceArgs'], pulumi.InputType['PhoenixLinkedServiceArgs'], pulumi.InputType['PostgreSqlLinkedServiceArgs'], pulumi.InputType['PrestoLinkedServiceArgs'], pulumi.InputType['QuickBooksLinkedServiceArgs'], pulumi.InputType['ResponsysLinkedServiceArgs'], pulumi.InputType['SalesforceLinkedServiceArgs'], pulumi.InputType['SalesforceMarketingCloudLinkedServiceArgs'], pulumi.InputType['SapBWLinkedServiceArgs'], pulumi.InputType['SapCloudForCustomerLinkedServiceArgs'], pulumi.InputType['SapEccLinkedServiceArgs'], pulumi.InputType['SapHanaLinkedServiceArgs'], pulumi.InputType['ServiceNowLinkedServiceArgs'], pulumi.InputType['SftpServerLinkedServiceArgs'], pulumi.InputType['ShopifyLinkedServiceArgs'], pulumi.InputType['SparkLinkedServiceArgs'], pulumi.InputType['SqlServerLinkedServiceArgs'], pulumi.InputType['SquareLinkedServiceArgs'], pulumi.InputType['SybaseLinkedServiceArgs'], pulumi.InputType['TeradataLinkedServiceArgs'], pulumi.InputType['VerticaLinkedServiceArgs'], pulumi.InputType['WebLinkedServiceArgs'], pulumi.InputType['XeroLinkedServiceArgs'], pulumi.InputType['ZohoLinkedServiceArgs']]] properties: Properties of linked service.
        :param pulumi.Input[str] resource_group_name: The resource group name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LinkedServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Linked service resource type.

        :param str resource_name: The name of the resource.
        :param LinkedServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LinkedServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 factory_name: Optional[pulumi.Input[str]] = None,
                 linked_service_name: Optional[pulumi.Input[str]] = None,
                 properties: Optional[pulumi.Input[Union[pulumi.InputType['AmazonMWSLinkedServiceArgs'], pulumi.InputType['AmazonRedshiftLinkedServiceArgs'], pulumi.InputType['AmazonS3LinkedServiceArgs'], pulumi.InputType['AzureBatchLinkedServiceArgs'], pulumi.InputType['AzureDataLakeAnalyticsLinkedServiceArgs'], pulumi.InputType['AzureDataLakeStoreLinkedServiceArgs'], pulumi.InputType['AzureDatabricksLinkedServiceArgs'], pulumi.InputType['AzureKeyVaultLinkedServiceArgs'], pulumi.InputType['AzureMLLinkedServiceArgs'], pulumi.InputType['AzureMySqlLinkedServiceArgs'], pulumi.InputType['AzurePostgreSqlLinkedServiceArgs'], pulumi.InputType['AzureSearchLinkedServiceArgs'], pulumi.InputType['AzureSqlDWLinkedServiceArgs'], pulumi.InputType['AzureSqlDatabaseLinkedServiceArgs'], pulumi.InputType['AzureStorageLinkedServiceArgs'], pulumi.InputType['CassandraLinkedServiceArgs'], pulumi.InputType['ConcurLinkedServiceArgs'], pulumi.InputType['CosmosDbLinkedServiceArgs'], pulumi.InputType['CouchbaseLinkedServiceArgs'], pulumi.InputType['CustomDataSourceLinkedServiceArgs'], pulumi.InputType['Db2LinkedServiceArgs'], pulumi.InputType['DrillLinkedServiceArgs'], pulumi.InputType['DynamicsLinkedServiceArgs'], pulumi.InputType['EloquaLinkedServiceArgs'], pulumi.InputType['FileServerLinkedServiceArgs'], pulumi.InputType['FtpServerLinkedServiceArgs'], pulumi.InputType['GoogleBigQueryLinkedServiceArgs'], pulumi.InputType['GreenplumLinkedServiceArgs'], pulumi.InputType['HBaseLinkedServiceArgs'], pulumi.InputType['HDInsightLinkedServiceArgs'], pulumi.InputType['HDInsightOnDemandLinkedServiceArgs'], pulumi.InputType['HdfsLinkedServiceArgs'], pulumi.InputType['HiveLinkedServiceArgs'], pulumi.InputType['HttpLinkedServiceArgs'], pulumi.InputType['HubspotLinkedServiceArgs'], pulumi.InputType['ImpalaLinkedServiceArgs'], pulumi.InputType['JiraLinkedServiceArgs'], pulumi.InputType['MagentoLinkedServiceArgs'], pulumi.InputType['MariaDBLinkedServiceArgs'], pulumi.InputType['MarketoLinkedServiceArgs'], pulumi.InputType['MongoDbLinkedServiceArgs'], pulumi.InputType['MySqlLinkedServiceArgs'], pulumi.InputType['NetezzaLinkedServiceArgs'], pulumi.InputType['ODataLinkedServiceArgs'], pulumi.InputType['OdbcLinkedServiceArgs'], pulumi.InputType['OracleLinkedServiceArgs'], pulumi.InputType['PaypalLinkedServiceArgs'], pulumi.InputType['PhoenixLinkedServiceArgs'], pulumi.InputType['PostgreSqlLinkedServiceArgs'], pulumi.InputType['PrestoLinkedServiceArgs'], pulumi.InputType['QuickBooksLinkedServiceArgs'], pulumi.InputType['ResponsysLinkedServiceArgs'], pulumi.InputType['SalesforceLinkedServiceArgs'], pulumi.InputType['SalesforceMarketingCloudLinkedServiceArgs'], pulumi.InputType['SapBWLinkedServiceArgs'], pulumi.InputType['SapCloudForCustomerLinkedServiceArgs'], pulumi.InputType['SapEccLinkedServiceArgs'], pulumi.InputType['SapHanaLinkedServiceArgs'], pulumi.InputType['ServiceNowLinkedServiceArgs'], pulumi.InputType['SftpServerLinkedServiceArgs'], pulumi.InputType['ShopifyLinkedServiceArgs'], pulumi.InputType['SparkLinkedServiceArgs'], pulumi.InputType['SqlServerLinkedServiceArgs'], pulumi.InputType['SquareLinkedServiceArgs'], pulumi.InputType['SybaseLinkedServiceArgs'], pulumi.InputType['TeradataLinkedServiceArgs'], pulumi.InputType['VerticaLinkedServiceArgs'], pulumi.InputType['WebLinkedServiceArgs'], pulumi.InputType['XeroLinkedServiceArgs'], pulumi.InputType['ZohoLinkedServiceArgs']]]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""LinkedService is deprecated: Version 2017-09-01-preview will be removed in v2 of the provider.""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LinkedServiceArgs.__new__(LinkedServiceArgs)

            if factory_name is None and not opts.urn:
                raise TypeError("Missing required property 'factory_name'")
            __props__.__dict__["factory_name"] = factory_name
            __props__.__dict__["linked_service_name"] = linked_service_name
            if properties is None and not opts.urn:
                raise TypeError("Missing required property 'properties'")
            __props__.__dict__["properties"] = properties
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["etag"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["type"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="azure-native:datafactory:LinkedService"), pulumi.Alias(type_="azure-native:datafactory/v20180601:LinkedService")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(LinkedService, __self__).__init__(
            'azure-native:datafactory/v20170901preview:LinkedService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'LinkedService':
        """
        Get an existing LinkedService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = LinkedServiceArgs.__new__(LinkedServiceArgs)

        __props__.__dict__["etag"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["properties"] = None
        __props__.__dict__["type"] = None
        return LinkedService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def etag(self) -> pulumi.Output[str]:
        """
        Etag identifies change in the resource.
        """
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The resource name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Any]:
        """
        Properties of linked service.
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The resource type.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities
from ._enums import *

__all__ = [
    'AppServiceCertificateResponse',
    'CertificateDetailsResponse',
]

@pulumi.output_type
class AppServiceCertificateResponse(dict):
    """
    Key Vault container for a certificate that is purchased through Azure.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "provisioningState":
            suggest = "provisioning_state"
        elif key == "keyVaultId":
            suggest = "key_vault_id"
        elif key == "keyVaultSecretName":
            suggest = "key_vault_secret_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppServiceCertificateResponse. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppServiceCertificateResponse.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppServiceCertificateResponse.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 provisioning_state: str,
                 key_vault_id: Optional[str] = None,
                 key_vault_secret_name: Optional[str] = None):
        """
        Key Vault container for a certificate that is purchased through Azure.
        :param str provisioning_state: Status of the Key Vault secret.
        :param str key_vault_id: Key Vault resource Id.
        :param str key_vault_secret_name: Key Vault secret name.
        """
        pulumi.set(__self__, "provisioning_state", provisioning_state)
        if key_vault_id is not None:
            pulumi.set(__self__, "key_vault_id", key_vault_id)
        if key_vault_secret_name is not None:
            pulumi.set(__self__, "key_vault_secret_name", key_vault_secret_name)

    @property
    @pulumi.getter(name="provisioningState")
    def provisioning_state(self) -> str:
        """
        Status of the Key Vault secret.
        """
        return pulumi.get(self, "provisioning_state")

    @property
    @pulumi.getter(name="keyVaultId")
    def key_vault_id(self) -> Optional[str]:
        """
        Key Vault resource Id.
        """
        return pulumi.get(self, "key_vault_id")

    @property
    @pulumi.getter(name="keyVaultSecretName")
    def key_vault_secret_name(self) -> Optional[str]:
        """
        Key Vault secret name.
        """
        return pulumi.get(self, "key_vault_secret_name")


@pulumi.output_type
class CertificateDetailsResponse(dict):
    """
    SSL certificate details.
    """
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "notAfter":
            suggest = "not_after"
        elif key == "notBefore":
            suggest = "not_before"
        elif key == "rawData":
            suggest = "raw_data"
        elif key == "serialNumber":
            suggest = "serial_number"
        elif key == "signatureAlgorithm":
            suggest = "signature_algorithm"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CertificateDetailsResponse. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CertificateDetailsResponse.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CertificateDetailsResponse.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 issuer: str,
                 not_after: str,
                 not_before: str,
                 raw_data: str,
                 serial_number: str,
                 signature_algorithm: str,
                 subject: str,
                 thumbprint: str,
                 version: int):
        """
        SSL certificate details.
        :param str issuer: Certificate Issuer.
        :param str not_after: Date Certificate is valid to.
        :param str not_before: Date Certificate is valid from.
        :param str raw_data: Raw certificate data.
        :param str serial_number: Certificate Serial Number.
        :param str signature_algorithm: Certificate Signature algorithm.
        :param str subject: Certificate Subject.
        :param str thumbprint: Certificate Thumbprint.
        :param int version: Certificate Version.
        """
        pulumi.set(__self__, "issuer", issuer)
        pulumi.set(__self__, "not_after", not_after)
        pulumi.set(__self__, "not_before", not_before)
        pulumi.set(__self__, "raw_data", raw_data)
        pulumi.set(__self__, "serial_number", serial_number)
        pulumi.set(__self__, "signature_algorithm", signature_algorithm)
        pulumi.set(__self__, "subject", subject)
        pulumi.set(__self__, "thumbprint", thumbprint)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def issuer(self) -> str:
        """
        Certificate Issuer.
        """
        return pulumi.get(self, "issuer")

    @property
    @pulumi.getter(name="notAfter")
    def not_after(self) -> str:
        """
        Date Certificate is valid to.
        """
        return pulumi.get(self, "not_after")

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> str:
        """
        Date Certificate is valid from.
        """
        return pulumi.get(self, "not_before")

    @property
    @pulumi.getter(name="rawData")
    def raw_data(self) -> str:
        """
        Raw certificate data.
        """
        return pulumi.get(self, "raw_data")

    @property
    @pulumi.getter(name="serialNumber")
    def serial_number(self) -> str:
        """
        Certificate Serial Number.
        """
        return pulumi.get(self, "serial_number")

    @property
    @pulumi.getter(name="signatureAlgorithm")
    def signature_algorithm(self) -> str:
        """
        Certificate Signature algorithm.
        """
        return pulumi.get(self, "signature_algorithm")

    @property
    @pulumi.getter
    def subject(self) -> str:
        """
        Certificate Subject.
        """
        return pulumi.get(self, "subject")

    @property
    @pulumi.getter
    def thumbprint(self) -> str:
        """
        Certificate Thumbprint.
        """
        return pulumi.get(self, "thumbprint")

    @property
    @pulumi.getter
    def version(self) -> int:
        """
        Certificate Version.
        """
        return pulumi.get(self, "version")


